$APING="bin/aping";
$FINGER="/usr/bin/finger";
$FPING="bin/fping";
$FWPING="bin/fwping";
$FTP="/bin/ftp";
$RPCINFO="/usr/sbin/rpcinfo";
$RUSERS="/usr/bin/rusers";
$RUP="/usr/bin/rup";
$SHOWMOUNT="bin/showmount";
$YPWHICH="/usr/bin/ypwhich";
$NSLOOKUP="/usr/bin/nslookup";
$DIG="/usr/bin/dig";
$XHOST="/usr/bin/X11/xhost";
$PING="/bin/ping";
$MOSAIC="/usr/local/netscape/netscape";
$TCP_SCAN="bin/tcp_scan";
$FTP_SCAN="bin/ftp-scan";
$UDP_SCAN="bin/udp_scan";
$FPING="bin/fping";
$NFS_CHK="bin/nfs-chk";
$YP_CHK="bin/yp-chk";
$SAFE_FINGER="bin/safe_finger";
$MD5="bin/md5";
$SYS_SOCKET="bin/sys_socket";
$BOOT="bin/boot";
$GET_TARGETS="bin/get_targets";
$TIMEOUT="bin/timeout";
$TPING="bin/tping";
$SAINT_CF="config/saint.cf";
$SERVICES="config/services";
$CAT="/bin/cat";
$MKNOD="/bin/mknod";
$MKFIFO="/bin/mkfifo";
$NMBLOOKUP="/usr/sbin/nmblookup";
$SMBCLIENT="/usr/bin/smbclient";
$NMAP="/usr/local/bin/nmap";
$DDOS="bin/ddos_scan";
